==> haskell-base-unicode-symbols-0.2.4.2-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-base-unicode-symbols.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 base-unicode-symbols
version:              0.2.4.2
visibility:           public
id:                   base-unicode-symbols-0.2.4.2-6HQW130bkmx2yCjqaWNHi2
key:                  base-unicode-symbols-0.2.4.2-6HQW130bkmx2yCjqaWNHi2
license:              BSD-3-Clause
copyright:            2009–2019 Roel van Dijk <roel@lambdacube.nl>
maintainer:           Roel van Dijk <roel@lambdacube.nl>
author:               Roel van Dijk <roel@lambdacube.nl>
stability:            provisional
homepage:             http://haskell.org/haskellwiki/Unicode-symbols
synopsis:             Unicode alternatives for common functions and operators
description:
    This package defines new symbols for a number of functions,
    operators and types in the base package.

    All symbols are documented with their actual definition and
    information regarding their Unicode code point. They should be
    completely interchangeable with their definitions.

    For further Unicode goodness you can enable the @UnicodeSyntax@
    language extension [1]. This extension enables Unicode characters
    to be used to stand for certain ASCII character sequences,
    i.e. &#x2192; instead of @->@, &#x2200; instead of @forall@ and many
    others.

    Original idea by P&#xE9;ter Divi&#xE1;nszky.

    \[1] <https://downloads.haskell.org/~ghc/latest/docs/html/users_guide/glasgow_exts.html#unicode-syntax>

abi:                  fb10a9dfdd4a7a31589b0a0f7f1ae793
exposed:              True
exposed-modules:
    Control.Applicative.Unicode Control.Arrow.Unicode
    Control.Category.Unicode Control.Monad.Unicode Data.Bool.Unicode
    Data.Eq.Unicode Data.Foldable.Unicode Data.Function.Unicode
    Data.List.Unicode Data.Monoid.Unicode Data.Ord.Unicode
    Data.String.Unicode Numeric.Natural.Unicode Prelude.Unicode

import-dirs:          /usr/lib/ghc-9.0.1/site-local/base-unicode-symbols-0.2.4.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/base-unicode-symbols-0.2.4.2
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/base-unicode-symbols-0.2.4.2

hs-libraries:         HSbase-unicode-symbols-0.2.4.2-6HQW130bkmx2yCjqaWNHi2
depends:              base-4.15.0.0
haddock-interfaces:
    /usr/share/doc/haskell-base-unicode-symbols/html/base-unicode-symbols.haddock

haddock-html:         /usr/share/doc/haskell-base-unicode-symbols/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-base-unicode-symbols-0.2.4.2-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-base-unicode-symbols.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 base-unicode-symbols
version:              0.2.4.2
visibility:           public
id:                   base-unicode-symbols-0.2.4.2-3I3pSMQwGEB5P9J2UkMzWs
key:                  base-unicode-symbols-0.2.4.2-3I3pSMQwGEB5P9J2UkMzWs
license:              BSD-3-Clause
copyright:            2009–2019 Roel van Dijk <roel@lambdacube.nl>
maintainer:           Roel van Dijk <roel@lambdacube.nl>
author:               Roel van Dijk <roel@lambdacube.nl>
stability:            provisional
homepage:             http://haskell.org/haskellwiki/Unicode-symbols
synopsis:             Unicode alternatives for common functions and operators
description:
    This package defines new symbols for a number of functions,
    operators and types in the base package.

    All symbols are documented with their actual definition and
    information regarding their Unicode code point. They should be
    completely interchangeable with their definitions.

    For further Unicode goodness you can enable the @UnicodeSyntax@
    language extension [1]. This extension enables Unicode characters
    to be used to stand for certain ASCII character sequences,
    i.e. &#x2192; instead of @->@, &#x2200; instead of @forall@ and many
    others.

    Original idea by P&#xE9;ter Divi&#xE1;nszky.

    \[1] <https://downloads.haskell.org/~ghc/latest/docs/html/users_guide/glasgow_exts.html#unicode-syntax>

abi:                  9c5f3e2028c7014ed82fee96be63edc9
exposed:              True
exposed-modules:
    Control.Applicative.Unicode Control.Arrow.Unicode
    Control.Category.Unicode Control.Monad.Unicode Data.Bool.Unicode
    Data.Eq.Unicode Data.Foldable.Unicode Data.Function.Unicode
    Data.List.Unicode Data.Monoid.Unicode Data.Ord.Unicode
    Data.String.Unicode Numeric.Natural.Unicode Prelude.Unicode

import-dirs:          /usr/lib/ghc-9.0.2/site-local/base-unicode-symbols-0.2.4.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/base-unicode-symbols-0.2.4.2
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.2/base-unicode-symbols-0.2.4.2

hs-libraries:         HSbase-unicode-symbols-0.2.4.2-3I3pSMQwGEB5P9J2UkMzWs
depends:              base-4.15.1.0
haddock-interfaces:
    /usr/share/doc/haskell-base-unicode-symbols/html/base-unicode-symbols.haddock

haddock-html:         /usr/share/doc/haskell-base-unicode-symbols/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
